@@ -128,6 +128,20 @@ func (x *Xlsx) createSchemaSheet(w *excl.Workbook, s *schema.Schema) error {
 	return nil
 }
 
+func (x *Xlsx) adjustColumnHeader(columnValues *[]string, hasColumn bool, name string) {
+	if hasColumn {
+		*columnValues = append(*columnValues, x.config.MergedDict.Lookup(name))
+	}
+}
+
+func adjustData(hasData bool, sheet *excl.Sheet, row int, column int, value string) int {
+	if hasData {
+		setStringWithBorder(sheet, row, column, value)
+		return column + 1
+	}
+	return column
+}
+
 func (x *Xlsx) createTableSheet(w *excl.Workbook, t *schema.Table) (e error) {
 	sheetName := t.Name
 	if utf8.RuneCountInString(sheetName) > 31 { // MS Excel assumes a maximum length of 31 characters for sheet name
@@ -155,20 +169,13 @@ func (x *Xlsx) createTableSheet(w *excl.Workbook, t *schema.Table) (e error) {
 		x.config.MergedDict.Lookup("Default"),
 		x.config.MergedDict.Lookup("Nullable"),
 	}
-	if t.HasColumnWithExtraDef() {
-		columnValues = append(columnValues, x.config.MergedDict.Lookup("Extra Definition"))
-	}
-	if t.HasColumnWithOccurrences() {
-		columnValues = append(columnValues, x.config.MergedDict.Lookup("Occurrences"))
-	}
-	if t.HasColumnWithPercents() {
-		columnValues = append(columnValues, x.config.MergedDict.Lookup("Percents"))
-	}
-	columnValues = append(columnValues, []string{
-		x.config.MergedDict.Lookup("Children"),
-		x.config.MergedDict.Lookup("Parents"),
-		x.config.MergedDict.Lookup("Comment"),
-	}...)
+	hideColumns := x.config.Format.HideColumnsWithoutValues
+	x.adjustColumnHeader(&columnValues, t.ShowColumn("ExtraDef", hideColumns), "Extra Definition")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn("Occurrences", hideColumns), "Occurrences")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn("Percents", hideColumns), "Percents")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn("Children", hideColumns), "Children")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn("Parents", hideColumns), "Parents")
+	x.adjustColumnHeader(&columnValues, t.ShowColumn("Comment", hideColumns), "Comment")
 	setHeader(sheet, 5, columnValues)
 	r := 6
 	for i, c := range t.Columns {
@@ -177,29 +184,20 @@ func (x *Xlsx) createTableSheet(w *excl.Workbook, t *schema.Table) (e error) {
 		setStringWithBorder(sheet, r+i, 3, c.Default.String)
 		setStringWithBorder(sheet, r+i, 4, fmt.Sprintf("%v", c.Nullable))
 		ci := 5
-		if t.HasColumnWithExtraDef() {
-			setStringWithBorder(sheet, r+i, ci, fmt.Sprintf("%v", c.ExtraDef))
-			ci = ci + 1
-		}
-		if t.HasColumnWithOccurrences() {
-			setStringWithBorder(sheet, r+i, ci, fmt.Sprintf("%d", c.Occurrences.Int32))
-			ci = ci + 1
-		}
-		if t.HasColumnWithPercents() {
-			setStringWithBorder(sheet, r+i, ci, fmt.Sprintf("%.1f", c.Percents.Float64))
-			ci = ci + 1
-		}
+		ci = adjustData(t.ShowColumn("ExtraDef", hideColumns), sheet, r+i, ci, fmt.Sprintf("%v", c.ExtraDef))
+		ci = adjustData(t.ShowColumn("Occurrences", hideColumns), sheet, r+i, ci, fmt.Sprintf("%d", c.Occurrences.Int32))
+		ci = adjustData(t.ShowColumn("Percent", hideColumns), sheet, r+i, ci, fmt.Sprintf("%.1f", c.Percents.Float64))
 		children := []string{}
 		for _, child := range c.ChildRelations {
 			children = append(children, child.Table.Name)
 		}
-		setStringWithBorder(sheet, r+i, ci+0, strings.Join(children, "\n"))
+		ci = adjustData(t.ShowColumn("Children", hideColumns), sheet, r+i, ci, strings.Join(children, "\n"))
 		parents := []string{}
 		for _, parent := range c.ParentRelations {
 			parents = append(parents, parent.ParentTable.Name)
 		}
-		setStringWithBorder(sheet, r+i, ci+1, strings.Join(parents, "\n"))
-		setStringWithBorder(sheet, r+i, ci+2, c.Comment)
+		ci = adjustData(t.ShowColumn("Parents", hideColumns), sheet, r+i, ci, strings.Join(parents, "\n"))
+		ci = adjustData(t.ShowColumn("Comment", hideColumns), sheet, r+i, ci, c.Comment)
 	}
 	r = r + len(t.Columns)
 
